# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/commanding/commands_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.api import httpbody_pb2 as yamcs_dot_api_dot_httpbody__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/commanding/commands_service.proto',
  package='yamcs.protobuf.commanding',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\024CommandsServiceProtoP\001',
  serialized_pb=b'\n0yamcs/protobuf/commanding/commands_service.proto\x12\x19yamcs.protobuf.commanding\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x18yamcs/api/httpbody.proto\x1a*yamcs/protobuf/commanding/commanding.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"\xd3\x01\n\x13ListCommandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0f\n\x03pos\x18\x02 \x01(\x03\x42\x02\x18\x01\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\r\n\x05order\x18\x04 \x01(\t\x12\t\n\x01q\x18\x05 \x01(\t\x12\x0c\n\x04next\x18\x06 \x01(\t\x12)\n\x05start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05queue\x18\t \x01(\t\"\xd5\x05\n\x13IssueCommandRequest\x12\x10\n\x08instance\x18\x06 \x01(\t\x12\x11\n\tprocessor\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12%\n\x04\x61rgs\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12Q\n\nassignment\x18\x01 \x03(\x0b\x32\x39.yamcs.protobuf.commanding.IssueCommandRequest.AssignmentB\x02\x18\x01\x12\x0e\n\x06origin\x18\x02 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x03 \x01(\x05\x12\x0e\n\x06\x64ryRun\x18\x04 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x05 \x01(\t\x12\x0e\n\x06stream\x18\x0b \x01(\t\x12&\n\x1e\x64isableTransmissionConstraints\x18\x0c \x01(\x08\x12\x18\n\x10\x64isableVerifiers\x18\r \x01(\x08\x12Z\n\x0everifierConfig\x18\x0e \x03(\x0b\x32\x42.yamcs.protobuf.commanding.IssueCommandRequest.VerifierConfigEntry\x12H\n\x05\x65xtra\x18\x0f \x03(\x0b\x32\x39.yamcs.protobuf.commanding.IssueCommandRequest.ExtraEntry\x1a)\n\nAssignment\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x1a`\n\x13VerifierConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).yamcs.protobuf.commanding.VerifierConfig:\x02\x38\x01\x1a\x43\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value:\x02\x38\x01\"\xa1\x03\n\x14IssueCommandResponse\x12\n\n\x02id\x18\x05 \x01(\t\x12\x32\n\x0egenerationTime\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x08 \x01(\x05\x12\x13\n\x0b\x63ommandName\x18\t \x01(\t\x12M\n\x07\x61liases\x18\x0e \x03(\x0b\x32<.yamcs.protobuf.commanding.IssueCommandResponse.AliasesEntry\x12\x41\n\x0b\x61ssignments\x18\x0c \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandAssignment\x12\x19\n\x11unprocessedBinary\x18\r \x01(\x0c\x12\x0e\n\x06\x62inary\x18\x04 \x01(\x0c\x12\x10\n\x08username\x18\x0b \x01(\t\x12\r\n\x05queue\x18\n \x01(\t\x1a.\n\x0c\x41liasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x1bUpdateCommandHistoryRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x46\n\nattributes\x18\x05 \x03(\x0b\x32\x32.yamcs.protobuf.commanding.CommandHistoryAttribute\"p\n\x14ListCommandsResponse\x12=\n\x05\x65ntry\x18\x01 \x03(\x0b\x32..yamcs.protobuf.commanding.CommandHistoryEntry\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"1\n\x11GetCommandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"4\n\x14\x45xportCommandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\x8c\x01\n\x15StreamCommandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x03(\t\"[\n\x18SubscribeCommandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x1a\n\x12ignorePastCommands\x18\x03 \x01(\x08\x32\xee\x08\n\x0b\x43ommandsApi\x12\xb1\x01\n\x0cIssueCommand\x12..yamcs.protobuf.commanding.IssueCommandRequest\x1a/.yamcs.protobuf.commanding.IssueCommandResponse\"@\x8a\x92\x03<\x1a\x37/api/processors/{instance}/{processor}/commands/{name*}:\x01*\x12\xae\x01\n\x14UpdateCommandHistory\x12\x36.yamcs.protobuf.commanding.UpdateCommandHistoryRequest\x1a\x16.google.protobuf.Empty\"F\x8a\x92\x03\x42\x1a=/api/processors/{instance}/{processor}/commandhistory/{name*}:\x01*\x12\x97\x01\n\x0cListCommands\x12..yamcs.protobuf.commanding.ListCommandsRequest\x1a/.yamcs.protobuf.commanding.ListCommandsResponse\"&\x8a\x92\x03\"\n /api/archive/{instance}/commands\x12\x97\x01\n\nGetCommand\x12,.yamcs.protobuf.commanding.GetCommandRequest\x1a..yamcs.protobuf.commanding.CommandHistoryEntry\"+\x8a\x92\x03\'\n%/api/archive/{instance}/commands/{id}\x12\xac\x01\n\x0eStreamCommands\x12\x30.yamcs.protobuf.commanding.StreamCommandsRequest\x1a..yamcs.protobuf.commanding.CommandHistoryEntry\"6\x8a\x92\x03\x32\x1a-/api/stream-archive/{instance}:streamCommands:\x01*0\x01\x12\x8a\x01\n\x11SubscribeCommands\x12\x33.yamcs.protobuf.commanding.SubscribeCommandsRequest\x1a..yamcs.protobuf.commanding.CommandHistoryEntry\"\x0e\xda\x92\x03\n\n\x08\x63ommands0\x01\x12\x89\x01\n\rExportCommand\x12/.yamcs.protobuf.commanding.ExportCommandRequest\x1a\x13.yamcs.api.HttpBody\"2\x8a\x92\x03.\n,/api/archive/{instance}/commands/{id}:exportB,\n\x12org.yamcs.protobufB\x14\x43ommandsServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_api_dot_httpbody__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_LISTCOMMANDSREQUEST = _descriptor.Descriptor(
  name='ListCommandsRequest',
  full_name='yamcs.protobuf.commanding.ListCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ListCommandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.commanding.ListCommandsRequest.pos', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.commanding.ListCommandsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.commanding.ListCommandsRequest.order', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.commanding.ListCommandsRequest.q', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.commanding.ListCommandsRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.commanding.ListCommandsRequest.start', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.commanding.ListCommandsRequest.stop', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.ListCommandsRequest.queue', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=510,
)


_ISSUECOMMANDREQUEST_ASSIGNMENT = _descriptor.Descriptor(
  name='Assignment',
  full_name='yamcs.protobuf.commanding.IssueCommandRequest.Assignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.IssueCommandRequest.Assignment.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.IssueCommandRequest.Assignment.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1030,
  serialized_end=1071,
)

_ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY = _descriptor.Descriptor(
  name='VerifierConfigEntry',
  full_name='yamcs.protobuf.commanding.IssueCommandRequest.VerifierConfigEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.commanding.IssueCommandRequest.VerifierConfigEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.IssueCommandRequest.VerifierConfigEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1073,
  serialized_end=1169,
)

_ISSUECOMMANDREQUEST_EXTRAENTRY = _descriptor.Descriptor(
  name='ExtraEntry',
  full_name='yamcs.protobuf.commanding.IssueCommandRequest.ExtraEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.commanding.IssueCommandRequest.ExtraEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.IssueCommandRequest.ExtraEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1171,
  serialized_end=1238,
)

_ISSUECOMMANDREQUEST = _descriptor.Descriptor(
  name='IssueCommandRequest',
  full_name='yamcs.protobuf.commanding.IssueCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.IssueCommandRequest.instance', index=0,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.IssueCommandRequest.processor', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.IssueCommandRequest.name', index=2,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='yamcs.protobuf.commanding.IssueCommandRequest.args', index=3,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignment', full_name='yamcs.protobuf.commanding.IssueCommandRequest.assignment', index=4,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.commanding.IssueCommandRequest.origin', index=5,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.IssueCommandRequest.sequenceNumber', index=6,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dryRun', full_name='yamcs.protobuf.commanding.IssueCommandRequest.dryRun', index=7,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comment', full_name='yamcs.protobuf.commanding.IssueCommandRequest.comment', index=8,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yamcs.protobuf.commanding.IssueCommandRequest.stream', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disableTransmissionConstraints', full_name='yamcs.protobuf.commanding.IssueCommandRequest.disableTransmissionConstraints', index=10,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disableVerifiers', full_name='yamcs.protobuf.commanding.IssueCommandRequest.disableVerifiers', index=11,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verifierConfig', full_name='yamcs.protobuf.commanding.IssueCommandRequest.verifierConfig', index=12,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='yamcs.protobuf.commanding.IssueCommandRequest.extra', index=13,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ISSUECOMMANDREQUEST_ASSIGNMENT, _ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY, _ISSUECOMMANDREQUEST_EXTRAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=1238,
)


_ISSUECOMMANDRESPONSE_ALIASESENTRY = _descriptor.Descriptor(
  name='AliasesEntry',
  full_name='yamcs.protobuf.commanding.IssueCommandResponse.AliasesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.commanding.IssueCommandResponse.AliasesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.commanding.IssueCommandResponse.AliasesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1612,
  serialized_end=1658,
)

_ISSUECOMMANDRESPONSE = _descriptor.Descriptor(
  name='IssueCommandResponse',
  full_name='yamcs.protobuf.commanding.IssueCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.IssueCommandResponse.id', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.commanding.IssueCommandResponse.generationTime', index=1,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin', full_name='yamcs.protobuf.commanding.IssueCommandResponse.origin', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.commanding.IssueCommandResponse.sequenceNumber', index=3,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandName', full_name='yamcs.protobuf.commanding.IssueCommandResponse.commandName', index=4,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='yamcs.protobuf.commanding.IssueCommandResponse.aliases', index=5,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='assignments', full_name='yamcs.protobuf.commanding.IssueCommandResponse.assignments', index=6,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unprocessedBinary', full_name='yamcs.protobuf.commanding.IssueCommandResponse.unprocessedBinary', index=7,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binary', full_name='yamcs.protobuf.commanding.IssueCommandResponse.binary', index=8,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.commanding.IssueCommandResponse.username', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.IssueCommandResponse.queue', index=10,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ISSUECOMMANDRESPONSE_ALIASESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1241,
  serialized_end=1658,
)


_UPDATECOMMANDHISTORYREQUEST = _descriptor.Descriptor(
  name='UpdateCommandHistoryRequest',
  full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest.id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='yamcs.protobuf.commanding.UpdateCommandHistoryRequest.attributes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1661,
  serialized_end=1825,
)


_LISTCOMMANDSRESPONSE = _descriptor.Descriptor(
  name='ListCommandsResponse',
  full_name='yamcs.protobuf.commanding.ListCommandsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.commanding.ListCommandsResponse.entry', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.commanding.ListCommandsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1827,
  serialized_end=1939,
)


_GETCOMMANDREQUEST = _descriptor.Descriptor(
  name='GetCommandRequest',
  full_name='yamcs.protobuf.commanding.GetCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.GetCommandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.GetCommandRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1941,
  serialized_end=1990,
)


_EXPORTCOMMANDREQUEST = _descriptor.Descriptor(
  name='ExportCommandRequest',
  full_name='yamcs.protobuf.commanding.ExportCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ExportCommandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.commanding.ExportCommandRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1992,
  serialized_end=2044,
)


_STREAMCOMMANDSREQUEST = _descriptor.Descriptor(
  name='StreamCommandsRequest',
  full_name='yamcs.protobuf.commanding.StreamCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.commanding.StreamCommandsRequest.name', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2047,
  serialized_end=2187,
)


_SUBSCRIBECOMMANDSREQUEST = _descriptor.Descriptor(
  name='SubscribeCommandsRequest',
  full_name='yamcs.protobuf.commanding.SubscribeCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.SubscribeCommandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.SubscribeCommandsRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignorePastCommands', full_name='yamcs.protobuf.commanding.SubscribeCommandsRequest.ignorePastCommands', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2189,
  serialized_end=2280,
)

_LISTCOMMANDSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMMANDSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ISSUECOMMANDREQUEST_ASSIGNMENT.containing_type = _ISSUECOMMANDREQUEST
_ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._VERIFIERCONFIG
_ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY.containing_type = _ISSUECOMMANDREQUEST
_ISSUECOMMANDREQUEST_EXTRAENTRY.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_ISSUECOMMANDREQUEST_EXTRAENTRY.containing_type = _ISSUECOMMANDREQUEST
_ISSUECOMMANDREQUEST.fields_by_name['args'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_ISSUECOMMANDREQUEST.fields_by_name['assignment'].message_type = _ISSUECOMMANDREQUEST_ASSIGNMENT
_ISSUECOMMANDREQUEST.fields_by_name['verifierConfig'].message_type = _ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY
_ISSUECOMMANDREQUEST.fields_by_name['extra'].message_type = _ISSUECOMMANDREQUEST_EXTRAENTRY
_ISSUECOMMANDRESPONSE_ALIASESENTRY.containing_type = _ISSUECOMMANDRESPONSE
_ISSUECOMMANDRESPONSE.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ISSUECOMMANDRESPONSE.fields_by_name['aliases'].message_type = _ISSUECOMMANDRESPONSE_ALIASESENTRY
_ISSUECOMMANDRESPONSE.fields_by_name['assignments'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDASSIGNMENT
_UPDATECOMMANDHISTORYREQUEST.fields_by_name['attributes'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYATTRIBUTE
_LISTCOMMANDSRESPONSE.fields_by_name['entry'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY
_STREAMCOMMANDSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMCOMMANDSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ListCommandsRequest'] = _LISTCOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandRequest'] = _ISSUECOMMANDREQUEST
DESCRIPTOR.message_types_by_name['IssueCommandResponse'] = _ISSUECOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['UpdateCommandHistoryRequest'] = _UPDATECOMMANDHISTORYREQUEST
DESCRIPTOR.message_types_by_name['ListCommandsResponse'] = _LISTCOMMANDSRESPONSE
DESCRIPTOR.message_types_by_name['GetCommandRequest'] = _GETCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['ExportCommandRequest'] = _EXPORTCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['StreamCommandsRequest'] = _STREAMCOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['SubscribeCommandsRequest'] = _SUBSCRIBECOMMANDSREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListCommandsRequest = _reflection.GeneratedProtocolMessageType('ListCommandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDSREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListCommandsRequest)
  })
_sym_db.RegisterMessage(ListCommandsRequest)

IssueCommandRequest = _reflection.GeneratedProtocolMessageType('IssueCommandRequest', (_message.Message,), {

  'Assignment' : _reflection.GeneratedProtocolMessageType('Assignment', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDREQUEST_ASSIGNMENT,
    '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandRequest.Assignment)
    })
  ,

  'VerifierConfigEntry' : _reflection.GeneratedProtocolMessageType('VerifierConfigEntry', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY,
    '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandRequest.VerifierConfigEntry)
    })
  ,

  'ExtraEntry' : _reflection.GeneratedProtocolMessageType('ExtraEntry', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDREQUEST_EXTRAENTRY,
    '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandRequest.ExtraEntry)
    })
  ,
  'DESCRIPTOR' : _ISSUECOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandRequest)
  })
_sym_db.RegisterMessage(IssueCommandRequest)
_sym_db.RegisterMessage(IssueCommandRequest.Assignment)
_sym_db.RegisterMessage(IssueCommandRequest.VerifierConfigEntry)
_sym_db.RegisterMessage(IssueCommandRequest.ExtraEntry)

IssueCommandResponse = _reflection.GeneratedProtocolMessageType('IssueCommandResponse', (_message.Message,), {

  'AliasesEntry' : _reflection.GeneratedProtocolMessageType('AliasesEntry', (_message.Message,), {
    'DESCRIPTOR' : _ISSUECOMMANDRESPONSE_ALIASESENTRY,
    '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandResponse.AliasesEntry)
    })
  ,
  'DESCRIPTOR' : _ISSUECOMMANDRESPONSE,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.IssueCommandResponse)
  })
_sym_db.RegisterMessage(IssueCommandResponse)
_sym_db.RegisterMessage(IssueCommandResponse.AliasesEntry)

UpdateCommandHistoryRequest = _reflection.GeneratedProtocolMessageType('UpdateCommandHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMMANDHISTORYREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.UpdateCommandHistoryRequest)
  })
_sym_db.RegisterMessage(UpdateCommandHistoryRequest)

ListCommandsResponse = _reflection.GeneratedProtocolMessageType('ListCommandsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDSRESPONSE,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListCommandsResponse)
  })
_sym_db.RegisterMessage(ListCommandsResponse)

GetCommandRequest = _reflection.GeneratedProtocolMessageType('GetCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.GetCommandRequest)
  })
_sym_db.RegisterMessage(GetCommandRequest)

ExportCommandRequest = _reflection.GeneratedProtocolMessageType('ExportCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTCOMMANDREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ExportCommandRequest)
  })
_sym_db.RegisterMessage(ExportCommandRequest)

StreamCommandsRequest = _reflection.GeneratedProtocolMessageType('StreamCommandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCOMMANDSREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.StreamCommandsRequest)
  })
_sym_db.RegisterMessage(StreamCommandsRequest)

SubscribeCommandsRequest = _reflection.GeneratedProtocolMessageType('SubscribeCommandsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBECOMMANDSREQUEST,
  '__module__' : 'yamcs.protobuf.commanding.commands_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.SubscribeCommandsRequest)
  })
_sym_db.RegisterMessage(SubscribeCommandsRequest)


DESCRIPTOR._options = None
_LISTCOMMANDSREQUEST.fields_by_name['pos']._options = None
_ISSUECOMMANDREQUEST_VERIFIERCONFIGENTRY._options = None
_ISSUECOMMANDREQUEST_EXTRAENTRY._options = None
_ISSUECOMMANDREQUEST.fields_by_name['assignment']._options = None
_ISSUECOMMANDRESPONSE_ALIASESENTRY._options = None

_COMMANDSAPI = _descriptor.ServiceDescriptor(
  name='CommandsApi',
  full_name='yamcs.protobuf.commanding.CommandsApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2283,
  serialized_end=3417,
  methods=[
  _descriptor.MethodDescriptor(
    name='IssueCommand',
    full_name='yamcs.protobuf.commanding.CommandsApi.IssueCommand',
    index=0,
    containing_service=None,
    input_type=_ISSUECOMMANDREQUEST,
    output_type=_ISSUECOMMANDRESPONSE,
    serialized_options=b'\212\222\003<\0327/api/processors/{instance}/{processor}/commands/{name*}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCommandHistory',
    full_name='yamcs.protobuf.commanding.CommandsApi.UpdateCommandHistory',
    index=1,
    containing_service=None,
    input_type=_UPDATECOMMANDHISTORYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003B\032=/api/processors/{instance}/{processor}/commandhistory/{name*}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='ListCommands',
    full_name='yamcs.protobuf.commanding.CommandsApi.ListCommands',
    index=2,
    containing_service=None,
    input_type=_LISTCOMMANDSREQUEST,
    output_type=_LISTCOMMANDSRESPONSE,
    serialized_options=b'\212\222\003\"\n /api/archive/{instance}/commands',
  ),
  _descriptor.MethodDescriptor(
    name='GetCommand',
    full_name='yamcs.protobuf.commanding.CommandsApi.GetCommand',
    index=3,
    containing_service=None,
    input_type=_GETCOMMANDREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY,
    serialized_options=b'\212\222\003\'\n%/api/archive/{instance}/commands/{id}',
  ),
  _descriptor.MethodDescriptor(
    name='StreamCommands',
    full_name='yamcs.protobuf.commanding.CommandsApi.StreamCommands',
    index=4,
    containing_service=None,
    input_type=_STREAMCOMMANDSREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY,
    serialized_options=b'\212\222\0032\032-/api/stream-archive/{instance}:streamCommands:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeCommands',
    full_name='yamcs.protobuf.commanding.CommandsApi.SubscribeCommands',
    index=5,
    containing_service=None,
    input_type=_SUBSCRIBECOMMANDSREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDHISTORYENTRY,
    serialized_options=b'\332\222\003\n\n\010commands',
  ),
  _descriptor.MethodDescriptor(
    name='ExportCommand',
    full_name='yamcs.protobuf.commanding.CommandsApi.ExportCommand',
    index=6,
    containing_service=None,
    input_type=_EXPORTCOMMANDREQUEST,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=b'\212\222\003.\n,/api/archive/{instance}/commands/{id}:export',
  ),
])
_sym_db.RegisterServiceDescriptor(_COMMANDSAPI)

DESCRIPTOR.services_by_name['CommandsApi'] = _COMMANDSAPI

# @@protoc_insertion_point(module_scope)



import functools
from typing import Callable, Mapping, Optional

from yamcs.core.context import Context
from yamcs.core.futures import WebSocketSubscriptionFuture
from yamcs.core.subscriptions import WebSocketSubscriptionManager
from yamcs.link.model import Cop1Config, Cop1Status
from yamcs.model import Link
from yamcs.protobuf.cop1 import cop1_pb2
from yamcs.protobuf.links import links_pb2


def _wrap_callback_parse_cop1_status(subscription, on_data, message):
    """
    Wraps a user callback to parse Cop1Status
    from a WebSocket data message
    """
    pb = cop1_pb2.Cop1Status()
    message.Unpack(pb)
    cop1_status = Cop1Status(pb)
    subscription._process(cop1_status)
    if on_data:
        on_data(cop1_status)


class Cop1Subscription(WebSocketSubscriptionFuture):
    """
    Local object providing access to COP1 status updates.
    """

    def __init__(self, manager):
        super(Cop1Subscription, self).__init__(manager)
        self._status = None

    def get_status(self) -> Optional[Cop1Status]:
        """
        Returns the latest known COP1 status.
        """
        return self._status

    @property
    def cop1_active(self) -> Optional[bool]:
        if self._status:
            return self._status.cop1_active
        return None

    @property
    def state(self) -> Optional[str]:
        if self._status:
            return self._status.state
        return None

    @property
    def bypass_all(self) -> Optional[bool]:
        if self._status:
            return self._status.bypass_all
        return None

    @property
    def v_s(self) -> Optional[int]:
        if self._status:
            return self._status.v_s
        return None

    @property
    def nn_r(self) -> Optional[int]:
        if self._status:
            return self._status.nn_r
        return None

    def _process(self, update):
        self._status = update


class LinkClient:
    """Client object that groups operations for a specific link."""

    def __init__(self, ctx: Context, instance: str, link: str):
        super(LinkClient, self).__init__()
        self.ctx = ctx
        self._instance = instance
        self._link = link

    def get_info(self) -> Link:
        """
        Get info on this link.
        """
        response = self.ctx.get_proto(f"/links/{self._instance}/{self._link}")
        message = links_pb2.LinkInfo()
        message.ParseFromString(response.content)
        return Link(message)

    def enable_link(self):
        """
        Enables this link.
        """
        req = links_pb2.EnableLinkRequest()
        url = f"/links/{self._instance}/{self._link}:enable"
        self.ctx.post_proto(url, data=req.SerializeToString())

    def disable_link(self):
        """
        Disables this link.
        """
        req = links_pb2.DisableLinkRequest()
        url = f"/links/{self._instance}/{self._link}:disable"
        self.ctx.post_proto(url, data=req.SerializeToString())

    def run_action(self, action: str, message: Optional[Mapping] = None):
        """
        Runs the given action for this link

        :param action:
            action identifier
        :param message:
            action message
        """
        req = links_pb2.RunActionRequest()
        if message:
            req.message.update(message)

        url = f"/links/{self._instance}/{self._link}/actions/{action}"
        self.ctx.post_proto(url, data=req.message.SerializeToString())

    def get_cop1_config(self) -> Cop1Config:
        """
        Gets the COP1 configuration for a data link.
        """
        response = self.ctx.get_proto(f"/cop1/{self._instance}/{self._link}/config")
        message = cop1_pb2.Cop1Config()
        message.ParseFromString(response.content)
        return Cop1Config(message)

    def update_cop1_config(
        self,
        window_width: Optional[int] = None,
        timeout_type: Optional[str] = None,
        tx_limit: Optional[int] = None,
        t1: Optional[float] = None,
    ) -> Cop1Config:
        """
        Sets the COP1 configuration for a data link.
        """
        req = cop1_pb2.Cop1Config()
        if window_width is not None:
            req.windowWidth = window_width
        if timeout_type is not None:
            req.timeoutType = cop1_pb2.TimeoutType.Value(timeout_type)
        if tx_limit is not None:
            req.txLimit = tx_limit
        if t1 is not None:
            req.t1 = int(round(1000 * t1))

        url = f"/cop1/{self._instance}/{self._link}/config"
        response = self.ctx.patch_proto(url, data=req.SerializeToString())

        message = cop1_pb2.Cop1Config()
        message.ParseFromString(response.content)
        return Cop1Config(message)

    def disable_cop1(self, bypass_all: bool = True):
        """
        Disable COP1 for a data link.

        :param bypass_all:
            All frames have bypass activated (i.e. they will be BD frames)
        """
        req = cop1_pb2.DisableRequest()
        req.setBypassAll = bypass_all
        url = f"/cop1/{self._instance}/{self._link}:disable"
        self.ctx.post_proto(url, data=req.SerializeToString())

    def initialize_cop1(
        self,
        type: str,
        clcw_wait_timeout: Optional[int] = None,
        v_r: Optional[int] = None,
    ):
        """
        Initialize COP1.

        :param type:
            One of ``WITH_CLCW_CHECK``, ``WITHOUT_CLCW_CHECK``,
            ``UNLOCK`` or ``SET_VR``
        :param clcw_wait_timeout:
            timeout in seconds used for the reception of
            CLCW. Required if type is ``WITH_CLCW_CHECK``
        :param v_r:
            value of v(R) if type is set to ``SET_VR``
        """
        req = cop1_pb2.InitializeRequest()
        req.type = cop1_pb2.InitializationType.Value(type)

        if clcw_wait_timeout is not None:
            req.clcwCheckInitializeTimeout = int(1000 * clcw_wait_timeout)
        if v_r is not None:
            req.vR = v_r

        url = f"/cop1/{self._instance}/{self._link}:initialize"
        self.ctx.post_proto(url, data=req.SerializeToString())

    def resume_cop1(self):
        """
        Resume COP1.
        """
        req = cop1_pb2.ResumeRequest()
        url = f"/cop1/{self._instance}/{self._link}:resume"
        self.ctx.post_proto(url, data=req.SerializeToString())

    def get_cop1_status(self) -> Cop1Status:
        """
        Retrieve the COP1 status.
        """
        response = self.ctx.get_proto(f"/cop1/{self._instance}/{self._link}/status")
        message = cop1_pb2.Cop1Status()
        message.ParseFromString(response.content)
        return Cop1Status(message)

    def create_cop1_subscription(
        self, on_data: Callable[[Cop1Status], None], timeout: float = 60
    ) -> Cop1Subscription:
        """
        Create a new subscription for receiving status of the COP1 link.

        This method returns a future, then returns immediately. Stop the
        subscription by canceling the future.

        :param on_data:
            Function that gets called on each :class:`.Cop1Status`.
        :param timeout:
            The amount of seconds to wait for the request to complete.
        :return:
            Future that can be used to manage the background websocket
            subscription.
        """
        options = cop1_pb2.SubscribeStatusRequest()
        options.instance = self._instance
        options.link = self._link

        manager = WebSocketSubscriptionManager(self.ctx, topic="cop1", options=options)

        # Represent subscription as a future
        subscription = Cop1Subscription(manager)

        wrapped_callback = functools.partial(
            _wrap_callback_parse_cop1_status, subscription, on_data
        )

        manager.open(wrapped_callback)

        # Wait until a reply or exception is received
        subscription.reply(timeout=timeout)

        return subscription



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/pvalue/pvalue_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/pvalue/pvalue_service.proto',
  package='yamcs.protobuf.pvalue',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\033ParameterValuesServiceProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/pvalue/pvalue_service.proto\x12\x15yamcs.protobuf.pvalue\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"{\n\x1aLoadParameterValuesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06stream\x18\x02 \x01(\t\x12;\n\x06values\x18\x03 \x03(\x0b\x32+.yamcs.protobuf.pvalue.ParameterValueUpdate\"\x9f\x01\n\x1bLoadParameterValuesResponse\x12\x12\n\nvalueCount\x18\x01 \x01(\r\x12\x35\n\x11minGenerationTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11maxGenerationTime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x96\x01\n\x14ParameterValueUpdate\x12\x11\n\tparameter\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\x12\x32\n\x0egenerationTime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\texpiresIn\x18\x04 \x01(\x04\x32\xd6\x01\n\x12ParameterValuesApi\x12\xbf\x01\n\x13LoadParameterValues\x12\x31.yamcs.protobuf.pvalue.LoadParameterValuesRequest\x1a\x32.yamcs.protobuf.pvalue.LoadParameterValuesResponse\"?\x8a\x92\x03;\x1a\x36/api/parameter-values/{instance}/streams/{stream}:load:\x01*(\x01\x42\x33\n\x12org.yamcs.protobufB\x1bParameterValuesServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_LOADPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='LoadParameterValuesRequest',
  full_name='yamcs.protobuf.pvalue.LoadParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.pvalue.LoadParameterValuesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yamcs.protobuf.pvalue.LoadParameterValuesRequest.stream', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='yamcs.protobuf.pvalue.LoadParameterValuesRequest.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=282,
)


_LOADPARAMETERVALUESRESPONSE = _descriptor.Descriptor(
  name='LoadParameterValuesResponse',
  full_name='yamcs.protobuf.pvalue.LoadParameterValuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='valueCount', full_name='yamcs.protobuf.pvalue.LoadParameterValuesResponse.valueCount', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minGenerationTime', full_name='yamcs.protobuf.pvalue.LoadParameterValuesResponse.minGenerationTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxGenerationTime', full_name='yamcs.protobuf.pvalue.LoadParameterValuesResponse.maxGenerationTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=285,
  serialized_end=444,
)


_PARAMETERVALUEUPDATE = _descriptor.Descriptor(
  name='ParameterValueUpdate',
  full_name='yamcs.protobuf.pvalue.ParameterValueUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.pvalue.ParameterValueUpdate.parameter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.pvalue.ParameterValueUpdate.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.pvalue.ParameterValueUpdate.generationTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiresIn', full_name='yamcs.protobuf.pvalue.ParameterValueUpdate.expiresIn', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=597,
)

_LOADPARAMETERVALUESREQUEST.fields_by_name['values'].message_type = _PARAMETERVALUEUPDATE
_LOADPARAMETERVALUESRESPONSE.fields_by_name['minGenerationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOADPARAMETERVALUESRESPONSE.fields_by_name['maxGenerationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARAMETERVALUEUPDATE.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_PARAMETERVALUEUPDATE.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['LoadParameterValuesRequest'] = _LOADPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['LoadParameterValuesResponse'] = _LOADPARAMETERVALUESRESPONSE
DESCRIPTOR.message_types_by_name['ParameterValueUpdate'] = _PARAMETERVALUEUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LoadParameterValuesRequest = _reflection.GeneratedProtocolMessageType('LoadParameterValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.pvalue.pvalue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.pvalue.LoadParameterValuesRequest)
  })
_sym_db.RegisterMessage(LoadParameterValuesRequest)

LoadParameterValuesResponse = _reflection.GeneratedProtocolMessageType('LoadParameterValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOADPARAMETERVALUESRESPONSE,
  '__module__' : 'yamcs.protobuf.pvalue.pvalue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.pvalue.LoadParameterValuesResponse)
  })
_sym_db.RegisterMessage(LoadParameterValuesResponse)

ParameterValueUpdate = _reflection.GeneratedProtocolMessageType('ParameterValueUpdate', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERVALUEUPDATE,
  '__module__' : 'yamcs.protobuf.pvalue.pvalue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.pvalue.ParameterValueUpdate)
  })
_sym_db.RegisterMessage(ParameterValueUpdate)


DESCRIPTOR._options = None

_PARAMETERVALUESAPI = _descriptor.ServiceDescriptor(
  name='ParameterValuesApi',
  full_name='yamcs.protobuf.pvalue.ParameterValuesApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=600,
  serialized_end=814,
  methods=[
  _descriptor.MethodDescriptor(
    name='LoadParameterValues',
    full_name='yamcs.protobuf.pvalue.ParameterValuesApi.LoadParameterValues',
    index=0,
    containing_service=None,
    input_type=_LOADPARAMETERVALUESREQUEST,
    output_type=_LOADPARAMETERVALUESRESPONSE,
    serialized_options=b'\212\222\003;\0326/api/parameter-values/{instance}/streams/{stream}:load:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_PARAMETERVALUESAPI)

DESCRIPTOR.services_by_name['ParameterValuesApi'] = _PARAMETERVALUESAPI

# @@protoc_insertion_point(module_scope)



from typing import Optional

from yamcs.protobuf.cop1 import cop1_pb2


class Cop1Status:
    """
    COP1 status
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def cop1_active(self) -> bool:
        return self._proto.cop1Active

    @property
    def state(self) -> Optional[str]:
        if self._proto.HasField("state"):
            return cop1_pb2.Cop1State.Name(self._proto.state)
        return None

    @property
    def bypass_all(self) -> Optional[bool]:
        if self._proto.HasField("setBypassAll"):
            return self._proto.setBypassAll
        return None

    @property
    def v_s(self) -> Optional[int]:
        if self._proto.HasField("vS"):
            return self._proto.vS
        return None

    @property
    def nn_r(self) -> Optional[int]:
        if self._proto.HasField("nnR"):
            return self._proto.nnR
        return None

    def __str__(self):
        line = f"COP1_ACTIVE: {self.cop1_active}"
        if self.cop1_active:
            return line + f", state: {self.state}, nn_r: {self.nn_r}, v_s: {self.v_s}"
        else:
            return line + f", bypass_all: {self.bypass_all}"


class Cop1Config:
    """
    COP1 configuration
    """

    def __init__(self, proto):
        self._proto = proto

    @property
    def vc_id(self) -> int:
        """
        Virtual Channel ID.
        """
        return self._proto.vcId

    @property
    def window_width(self) -> int:
        return self._proto.windowWidth

    @property
    def timeout_type(self) -> str:
        return cop1_pb2.TimeoutType.Name(self._proto.timeoutType)

    @property
    def tx_limit(self) -> int:
        return self._proto.txLimit

    @property
    def t1(self) -> float:
        return self._proto.t1 / 1000.0

    def __str__(self):
        res = f"VC_ID: {self.vc_id}, win: {self.window_width}"
        res += f", timeout_type: {self.timeout_type}"
        return res + f", tx_limit: {self.tx_limit}, t1: {self.t1}"



import functools
import json
from typing import Any, Callable, Iterable, List, Mapping, Optional

from yamcs.core.context import Context
from yamcs.core.exceptions import NotFound
from yamcs.core.futures import WebSocketSubscriptionFuture
from yamcs.core.subscriptions import WebSocketSubscriptionManager
from yamcs.filetransfer.model import RemoteFileListing, Service, Transfer
from yamcs.protobuf.filetransfer import filetransfer_pb2


def _wrap_callback_parse_transfer_data(subscription, on_data, message):
    """
    Wraps an (optional) user callback to parse TransferInfo
    from a WebSocket data message
    """
    pb = filetransfer_pb2.TransferInfo()
    message.Unpack(pb)
    transfer = subscription._process(pb)
    if on_data:
        on_data(transfer)


def _wrap_callback_parse_filelist_data(subscription, on_data, message):
    """
    Wraps an (optional) user callback to parse ListFilesResponse
    from a WebSocket data message
    """
    pb = filetransfer_pb2.ListFilesResponse()
    message.Unpack(pb)
    filelist = subscription._process(pb)
    if on_data:
        on_data(filelist)


class TransferSubscription(WebSocketSubscriptionFuture):
    """
    Local object providing access to transfer updates.

    A subscription object stores the last transfer info for
    each transfer.
    """

    def __init__(self, manager, service_client: "ServiceClient"):
        super(TransferSubscription, self).__init__(manager)
        self.service_client = service_client
        self._cache = {}
        """Transfer cache keyed by id."""

    def get_transfer(self, id: str) -> Optional[Transfer]:
        """
        Returns the latest transfer state.

        :param id:
            Transfer identifier
        """
        if id in self._cache:
            return self._cache[id]
        return None

    def list_transfers(self) -> List[Transfer]:
        """
        Returns a snapshot of all transfer info.
        """
        return [self._cache[k] for k in self._cache]

    def list_ongoing(self) -> List[Transfer]:
        """
        Returns all ongoing transfers.
        """
        return [t for t in self.list_transfers() if not t.is_complete()]

    def list_completed(self) -> List[Transfer]:
        """
        Returns all completed transfers (successful or not).
        """
        return [t for t in self.list_transfers() if t.is_complete()]

    def _process(self, proto) -> Transfer:
        if proto.id in self._cache:
            transfer = self._cache[proto.id]
            transfer._proto = proto
        else:
            transfer = Transfer(proto, service_client=self.service_client)
            self._cache[transfer.id] = transfer

        return transfer


class FileListSubscription(WebSocketSubscriptionFuture):
    """
    Local object providing access to filelist updates.

    A subscription object stores the last filelist info for
    each remotepath and destination.
    """

    def __init__(self, manager):
        super(FileListSubscription, self).__init__(manager)
        self._cache = {}
        """Filelist cache keyed by (destination, remotePath)"""

    def get_filelist(
        self, remote_path: str, destination: str
    ) -> Optional[RemoteFileListing]:
        """
        Get the latest cached filelist for the given remote path and destination

        :param remote_path:
            path on the remote destination
        :param destination:
            remote entity name
        """
        return self._cache.get((remote_path, destination))

    def _process(self, proto) -> RemoteFileListing:
        filelist = RemoteFileListing(proto)
        self._cache[(filelist.destination, filelist.remote_path)] = filelist
        return filelist


class FileTransferClient:
    """
    Client for working with file transfers (e.g. CFDP) managed by Yamcs.
    """

    def __init__(self, ctx: Context, instance: str):
        super(FileTransferClient, self).__init__()
        self.ctx = ctx
        self._instance = instance
        self._default_service = None

    def list_services(self) -> Iterable[Service]:
        """
        List the services.
        """
        # Server does not do pagination on listings of this resource.
        # Return an iterator anyway for similarity with other API methods
        response = self.ctx.get_proto(path=f"/filetransfer/{self._instance}/services")
        message = filetransfer_pb2.ListFileTransferServicesResponse()
        message.ParseFromString(response.content)
        services = getattr(message, "services")
        result = []
        for proto in services:
            service_client = ServiceClient(self.ctx, proto)
            result.append(Service(proto, service_client))
        return iter(result)

    def get_service(self, name: str) -> Service:
        """
        Get a specific File Transfer service.

        :param name:
            The service name.
        """
        # TODO should have an actual server-side operation for this
        for service in self.list_services():
            if service.name == name:
                return service
        raise NotFound()


class ServiceClient:
    def __init__(self, ctx: Context, proto):
        self.ctx = ctx
        self._instance = proto.instance
        self._service = proto.name

    def upload(
        self,
        bucket_name: str,
        object_name: str,
        remote_path: str,
        source_entity: str,
        destination_entity: str,
        overwrite: bool,
        parents: bool,
        reliable: bool,
        options: Mapping[str, Any],
    ) -> Transfer:
        req = filetransfer_pb2.CreateTransferRequest()
        req.direction = filetransfer_pb2.TransferDirection.UPLOAD
        req.bucket = bucket_name
        req.objectName = object_name
        req.remotePath = remote_path
        if source_entity:
            req.source = source_entity
        if destination_entity:
            req.destination = destination_entity

        # Old options for backwards compatibility
        old_options = {
            "overwrite": overwrite,
            "createPath": parents,
            "reliable": reliable,
        }
        req.options.update(old_options)
        if options:
            req.options.update(options)

        url = f"/filetransfer/{self._instance}/{self._service}/transfers"
        response = self.ctx.post_proto(url, data=req.SerializeToString())
        message = filetransfer_pb2.TransferInfo()
        message.ParseFromString(response.content)
        return Transfer(message, self)

    def download(
        self,
        bucket_name: str,
        remote_path: str,
        object_name: str,
        source_entity: str,
        destination_entity: str,
        overwrite: bool,
        parents: bool,
        reliable: bool,
        options: Mapping[str, Any],
    ) -> Transfer:
        req = filetransfer_pb2.CreateTransferRequest()
        req.direction = filetransfer_pb2.TransferDirection.DOWNLOAD
        req.bucket = bucket_name
        req.remotePath = remote_path
        if object_name:
            req.objectName = object_name
        if source_entity:
            req.source = source_entity
        if destination_entity:
            req.destination = destination_entity

        # Old options for backwards compatibility
        old_options = {
            "overwrite": overwrite,
            "createPath": parents,
            "reliable": reliable,
        }
        req.options.update(old_options)
        if options:
            req.options.update(options)

        url = f"/filetransfer/{self._instance}/{self._service}/transfers"
        response = self.ctx.post_proto(url, data=req.SerializeToString())
        message = filetransfer_pb2.TransferInfo()
        message.ParseFromString(response.content)
        return Transfer(message, self)

    def fetch_filelist(
        self,
        remote_path: str,
        source_entity: str,
        destination_entity: str,
        options: Mapping[str, Any],
    ):
        req = filetransfer_pb2.ListFilesRequest()
        req.remotePath = remote_path
        if source_entity:
            req.source = source_entity
        if destination_entity:
            req.destination = destination_entity
        if options:
            req.options.update(options)
        url = f"/filetransfer/{self._instance}/{self._service}/files:sync"
        self.ctx.post_proto(url, data=req.SerializeToString())

    def get_filelist(
        self,
        remote_path: str,
        source_entity: str,
        destination_entity: str,
        options: Mapping[str, Any],
    ) -> RemoteFileListing:
        params = {"remotePath": remote_path}
        if source_entity:
            params["source"] = source_entity
        if destination_entity:
            params["destination"] = destination_entity
        if options:
            params["options"] = json.dumps(options)
        url = f"/filetransfer/{self._instance}/{self._service}/files"
        response = self.ctx.get_proto(url, params=params)
        message = filetransfer_pb2.ListFilesResponse()
        message.ParseFromString(response.content)
        return RemoteFileListing(message)

    def pause_transfer(self, id: str):
        url = f"/filetransfer/{self._instance}/{self._service}/transfers/{id}:pause"
        self.ctx.post_proto(url)

    def resume_transfer(self, id: str):
        url = f"/filetransfer/{self._instance}/{self._service}/transfers/{id}:resume"
        self.ctx.post_proto(url)

    def cancel_transfer(self, id: str):
        url = f"/filetransfer/{self._instance}/{self._service}/transfers/{id}:cancel"
        self.ctx.post_proto(url)

    def create_transfer_subscription(
        self, on_data: Optional[Callable[[Transfer], None]] = None, timeout: float = 60
    ) -> TransferSubscription:
        options = filetransfer_pb2.SubscribeTransfersRequest()
        options.instance = self._instance
        options.serviceName = self._service

        manager = WebSocketSubscriptionManager(
            self.ctx, topic="file-transfers", options=options
        )

        # Represent subscription as a future
        subscription = TransferSubscription(manager, self)

        wrapped_callback = functools.partial(
            _wrap_callback_parse_transfer_data, subscription, on_data
        )

        manager.open(wrapped_callback)

        # Wait until a reply or exception is received
        subscription.reply(timeout=timeout)

        return subscription

    def create_filelist_subscription(
        self,
        on_data: Optional[Callable[[RemoteFileListing], None]] = None,
        timeout: float = 60,
    ) -> FileListSubscription:
        options = filetransfer_pb2.SubscribeTransfersRequest()
        options.instance = self._instance
        options.serviceName = self._service

        manager = WebSocketSubscriptionManager(
            self.ctx, topic="remote-file-list", options=options
        )

        # Represent subscription as a future
        subscription = FileListSubscription(manager)

        wrapped_callback = functools.partial(
            _wrap_callback_parse_filelist_data, subscription, on_data
        )

        manager.open(wrapped_callback)

        # Wait until a reply or exception is received
        subscription.reply(timeout=timeout)

        return subscription



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/activities/activities_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.activities import activities_pb2 as yamcs_dot_protobuf_dot_activities_dot_activities__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/activities/activities_service.proto',
  package='yamcs.protobuf.activities',
  syntax='proto2',
  serialized_options=b'\n\035org.yamcs.protobuf.activitiesB\026ActivitiesServiceProtoP\001',
  serialized_pb=b'\n2yamcs/protobuf/activities/activities_service.proto\x12\x19yamcs.protobuf.activities\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a*yamcs/protobuf/activities/activities.proto\"\xd3\x01\n\x15ListActivitiesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\r\n\x05order\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x03(\t\x12\x0c\n\x04type\x18\x05 \x03(\t\x12\x0c\n\x04next\x18\x06 \x01(\t\x12)\n\x05start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\t\n\x01q\x18\t \x01(\t\"8\n\x12GetActivityRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tivity\x18\x02 \x01(\t\";\n\x15GetActivityLogRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tivity\x18\x02 \x01(\t\"R\n\x16GetActivityLogResponse\x12\x38\n\x04logs\x18\x01 \x03(\x0b\x32*.yamcs.protobuf.activities.ActivityLogInfo\"p\n\x16ListActivitiesResponse\x12;\n\nactivities\x18\x01 \x03(\x0b\x32\'.yamcs.protobuf.activities.ActivityInfo\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"(\n\x14ListExecutorsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"S\n\x15ListExecutorsResponse\x12:\n\texecutors\x18\x01 \x03(\x0b\x32\'.yamcs.protobuf.activities.ExecutorInfo\"&\n\x12ListScriptsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"&\n\x13ListScriptsResponse\x12\x0f\n\x07scripts\x18\x01 \x03(\t\"w\n\x14StartActivityRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12M\n\x12\x61\x63tivityDefinition\x18\x02 \x01(\x0b\x32\x31.yamcs.protobuf.activities.ActivityDefinitionInfo\";\n\x15\x43\x61ncelActivityRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tivity\x18\x02 \x01(\t\"Z\n\x1d\x43ompleteManualActivityRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tivity\x18\x02 \x01(\t\x12\x15\n\rfailureReason\x18\x03 \x01(\t\".\n\x1aSubscribeActivitiesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"A\n\x1bSubscribeActivityLogRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x10\n\x08\x61\x63tivity\x18\x02 \x01(\t\"0\n\x1cSubscribeGlobalStatusRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\",\n\x14GlobalActivityStatus\x12\x14\n\x0congoingCount\x18\x01 \x01(\x05\x32\xa1\x0e\n\rActivitiesApi\x12\xa2\x01\n\x0eListActivities\x12\x30.yamcs.protobuf.activities.ListActivitiesRequest\x1a\x31.yamcs.protobuf.activities.ListActivitiesResponse\"+\x8a\x92\x03\'\n%/api/activities/{instance}/activities\x12\x9d\x01\n\x0bGetActivity\x12-.yamcs.protobuf.activities.GetActivityRequest\x1a\'.yamcs.protobuf.activities.ActivityInfo\"6\x8a\x92\x03\x32\n0/api/activities/{instance}/activities/{activity}\x12\xb1\x01\n\x0eGetActivityLog\x12\x30.yamcs.protobuf.activities.GetActivityLogRequest\x1a\x31.yamcs.protobuf.activities.GetActivityLogResponse\":\x8a\x92\x03\x36\n4/api/activities/{instance}/activities/{activity}/log\x12\xaa\x01\n\rStartActivity\x12/.yamcs.protobuf.activities.StartActivityRequest\x1a\'.yamcs.protobuf.activities.ActivityInfo\"?\x8a\x92\x03;\x1a%/api/activities/{instance}/activities:\x12\x61\x63tivityDefinition\x12\xaa\x01\n\x0e\x43\x61ncelActivity\x12\x30.yamcs.protobuf.activities.CancelActivityRequest\x1a\'.yamcs.protobuf.activities.ActivityInfo\"=\x8a\x92\x03\x39\x1a\x37/api/activities/{instance}/activities/{activity}:cancel\x12\xbf\x01\n\x16\x43ompleteManualActivity\x12\x38.yamcs.protobuf.activities.CompleteManualActivityRequest\x1a\'.yamcs.protobuf.activities.ActivityInfo\"B\x8a\x92\x03>\x1a\x39/api/activities/{instance}/activities/{activity}:complete:\x01*\x12\xa1\x01\n\x15SubscribeGlobalStatus\x12\x37.yamcs.protobuf.activities.SubscribeGlobalStatusRequest\x1a/.yamcs.protobuf.activities.GlobalActivityStatus\"\x1c\xda\x92\x03\x18\n\x16global-activity-status0\x01\x12\x89\x01\n\x13SubscribeActivities\x12\x35.yamcs.protobuf.activities.SubscribeActivitiesRequest\x1a\'.yamcs.protobuf.activities.ActivityInfo\"\x10\xda\x92\x03\x0c\n\nactivities0\x01\x12\x90\x01\n\x14SubscribeActivityLog\x12\x36.yamcs.protobuf.activities.SubscribeActivityLogRequest\x1a*.yamcs.protobuf.activities.ActivityLogInfo\"\x12\xda\x92\x03\x0e\n\x0c\x61\x63tivity-log0\x01\x12\x9e\x01\n\rListExecutors\x12/.yamcs.protobuf.activities.ListExecutorsRequest\x1a\x30.yamcs.protobuf.activities.ListExecutorsResponse\"*\x8a\x92\x03&\n$/api/activities/{instance}/executors\x12\x96\x01\n\x0bListScripts\x12-.yamcs.protobuf.activities.ListScriptsRequest\x1a..yamcs.protobuf.activities.ListScriptsResponse\"(\x8a\x92\x03$\n\"/api/activities/{instance}/scriptsB9\n\x1dorg.yamcs.protobuf.activitiesB\x16\x41\x63tivitiesServiceProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_activities_dot_activities__pb2.DESCRIPTOR,])




_LISTACTIVITIESREQUEST = _descriptor.Descriptor(
  name='ListActivitiesRequest',
  full_name='yamcs.protobuf.activities.ListActivitiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.ListActivitiesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.activities.ListActivitiesRequest.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.activities.ListActivitiesRequest.order', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='yamcs.protobuf.activities.ListActivitiesRequest.status', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.activities.ListActivitiesRequest.type', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.activities.ListActivitiesRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.activities.ListActivitiesRequest.start', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.activities.ListActivitiesRequest.stop', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.activities.ListActivitiesRequest.q', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=399,
)


_GETACTIVITYREQUEST = _descriptor.Descriptor(
  name='GetActivityRequest',
  full_name='yamcs.protobuf.activities.GetActivityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.GetActivityRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activity', full_name='yamcs.protobuf.activities.GetActivityRequest.activity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=457,
)


_GETACTIVITYLOGREQUEST = _descriptor.Descriptor(
  name='GetActivityLogRequest',
  full_name='yamcs.protobuf.activities.GetActivityLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.GetActivityLogRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activity', full_name='yamcs.protobuf.activities.GetActivityLogRequest.activity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=518,
)


_GETACTIVITYLOGRESPONSE = _descriptor.Descriptor(
  name='GetActivityLogResponse',
  full_name='yamcs.protobuf.activities.GetActivityLogResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logs', full_name='yamcs.protobuf.activities.GetActivityLogResponse.logs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=602,
)


_LISTACTIVITIESRESPONSE = _descriptor.Descriptor(
  name='ListActivitiesResponse',
  full_name='yamcs.protobuf.activities.ListActivitiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='activities', full_name='yamcs.protobuf.activities.ListActivitiesResponse.activities', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.activities.ListActivitiesResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=716,
)


_LISTEXECUTORSREQUEST = _descriptor.Descriptor(
  name='ListExecutorsRequest',
  full_name='yamcs.protobuf.activities.ListExecutorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.ListExecutorsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=758,
)


_LISTEXECUTORSRESPONSE = _descriptor.Descriptor(
  name='ListExecutorsResponse',
  full_name='yamcs.protobuf.activities.ListExecutorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executors', full_name='yamcs.protobuf.activities.ListExecutorsResponse.executors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=760,
  serialized_end=843,
)


_LISTSCRIPTSREQUEST = _descriptor.Descriptor(
  name='ListScriptsRequest',
  full_name='yamcs.protobuf.activities.ListScriptsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.ListScriptsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=883,
)


_LISTSCRIPTSRESPONSE = _descriptor.Descriptor(
  name='ListScriptsResponse',
  full_name='yamcs.protobuf.activities.ListScriptsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scripts', full_name='yamcs.protobuf.activities.ListScriptsResponse.scripts', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=885,
  serialized_end=923,
)


_STARTACTIVITYREQUEST = _descriptor.Descriptor(
  name='StartActivityRequest',
  full_name='yamcs.protobuf.activities.StartActivityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.StartActivityRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activityDefinition', full_name='yamcs.protobuf.activities.StartActivityRequest.activityDefinition', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=1044,
)


_CANCELACTIVITYREQUEST = _descriptor.Descriptor(
  name='CancelActivityRequest',
  full_name='yamcs.protobuf.activities.CancelActivityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.CancelActivityRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activity', full_name='yamcs.protobuf.activities.CancelActivityRequest.activity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1046,
  serialized_end=1105,
)


_COMPLETEMANUALACTIVITYREQUEST = _descriptor.Descriptor(
  name='CompleteManualActivityRequest',
  full_name='yamcs.protobuf.activities.CompleteManualActivityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.CompleteManualActivityRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activity', full_name='yamcs.protobuf.activities.CompleteManualActivityRequest.activity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureReason', full_name='yamcs.protobuf.activities.CompleteManualActivityRequest.failureReason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1197,
)


_SUBSCRIBEACTIVITIESREQUEST = _descriptor.Descriptor(
  name='SubscribeActivitiesRequest',
  full_name='yamcs.protobuf.activities.SubscribeActivitiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.SubscribeActivitiesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1199,
  serialized_end=1245,
)


_SUBSCRIBEACTIVITYLOGREQUEST = _descriptor.Descriptor(
  name='SubscribeActivityLogRequest',
  full_name='yamcs.protobuf.activities.SubscribeActivityLogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.SubscribeActivityLogRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activity', full_name='yamcs.protobuf.activities.SubscribeActivityLogRequest.activity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1312,
)


_SUBSCRIBEGLOBALSTATUSREQUEST = _descriptor.Descriptor(
  name='SubscribeGlobalStatusRequest',
  full_name='yamcs.protobuf.activities.SubscribeGlobalStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.activities.SubscribeGlobalStatusRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1314,
  serialized_end=1362,
)


_GLOBALACTIVITYSTATUS = _descriptor.Descriptor(
  name='GlobalActivityStatus',
  full_name='yamcs.protobuf.activities.GlobalActivityStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ongoingCount', full_name='yamcs.protobuf.activities.GlobalActivityStatus.ongoingCount', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1364,
  serialized_end=1408,
)

_LISTACTIVITIESREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTACTIVITIESREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETACTIVITYLOGRESPONSE.fields_by_name['logs'].message_type = yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYLOGINFO
_LISTACTIVITIESRESPONSE.fields_by_name['activities'].message_type = yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYINFO
_LISTEXECUTORSRESPONSE.fields_by_name['executors'].message_type = yamcs_dot_protobuf_dot_activities_dot_activities__pb2._EXECUTORINFO
_STARTACTIVITYREQUEST.fields_by_name['activityDefinition'].message_type = yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYDEFINITIONINFO
DESCRIPTOR.message_types_by_name['ListActivitiesRequest'] = _LISTACTIVITIESREQUEST
DESCRIPTOR.message_types_by_name['GetActivityRequest'] = _GETACTIVITYREQUEST
DESCRIPTOR.message_types_by_name['GetActivityLogRequest'] = _GETACTIVITYLOGREQUEST
DESCRIPTOR.message_types_by_name['GetActivityLogResponse'] = _GETACTIVITYLOGRESPONSE
DESCRIPTOR.message_types_by_name['ListActivitiesResponse'] = _LISTACTIVITIESRESPONSE
DESCRIPTOR.message_types_by_name['ListExecutorsRequest'] = _LISTEXECUTORSREQUEST
DESCRIPTOR.message_types_by_name['ListExecutorsResponse'] = _LISTEXECUTORSRESPONSE
DESCRIPTOR.message_types_by_name['ListScriptsRequest'] = _LISTSCRIPTSREQUEST
DESCRIPTOR.message_types_by_name['ListScriptsResponse'] = _LISTSCRIPTSRESPONSE
DESCRIPTOR.message_types_by_name['StartActivityRequest'] = _STARTACTIVITYREQUEST
DESCRIPTOR.message_types_by_name['CancelActivityRequest'] = _CANCELACTIVITYREQUEST
DESCRIPTOR.message_types_by_name['CompleteManualActivityRequest'] = _COMPLETEMANUALACTIVITYREQUEST
DESCRIPTOR.message_types_by_name['SubscribeActivitiesRequest'] = _SUBSCRIBEACTIVITIESREQUEST
DESCRIPTOR.message_types_by_name['SubscribeActivityLogRequest'] = _SUBSCRIBEACTIVITYLOGREQUEST
DESCRIPTOR.message_types_by_name['SubscribeGlobalStatusRequest'] = _SUBSCRIBEGLOBALSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GlobalActivityStatus'] = _GLOBALACTIVITYSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListActivitiesRequest = _reflection.GeneratedProtocolMessageType('ListActivitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACTIVITIESREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ListActivitiesRequest)
  })
_sym_db.RegisterMessage(ListActivitiesRequest)

GetActivityRequest = _reflection.GeneratedProtocolMessageType('GetActivityRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVITYREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.GetActivityRequest)
  })
_sym_db.RegisterMessage(GetActivityRequest)

GetActivityLogRequest = _reflection.GeneratedProtocolMessageType('GetActivityLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVITYLOGREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.GetActivityLogRequest)
  })
_sym_db.RegisterMessage(GetActivityLogRequest)

GetActivityLogResponse = _reflection.GeneratedProtocolMessageType('GetActivityLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACTIVITYLOGRESPONSE,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.GetActivityLogResponse)
  })
_sym_db.RegisterMessage(GetActivityLogResponse)

ListActivitiesResponse = _reflection.GeneratedProtocolMessageType('ListActivitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACTIVITIESRESPONSE,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ListActivitiesResponse)
  })
_sym_db.RegisterMessage(ListActivitiesResponse)

ListExecutorsRequest = _reflection.GeneratedProtocolMessageType('ListExecutorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXECUTORSREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ListExecutorsRequest)
  })
_sym_db.RegisterMessage(ListExecutorsRequest)

ListExecutorsResponse = _reflection.GeneratedProtocolMessageType('ListExecutorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXECUTORSRESPONSE,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ListExecutorsResponse)
  })
_sym_db.RegisterMessage(ListExecutorsResponse)

ListScriptsRequest = _reflection.GeneratedProtocolMessageType('ListScriptsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCRIPTSREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ListScriptsRequest)
  })
_sym_db.RegisterMessage(ListScriptsRequest)

ListScriptsResponse = _reflection.GeneratedProtocolMessageType('ListScriptsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCRIPTSRESPONSE,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.ListScriptsResponse)
  })
_sym_db.RegisterMessage(ListScriptsResponse)

StartActivityRequest = _reflection.GeneratedProtocolMessageType('StartActivityRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTACTIVITYREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.StartActivityRequest)
  })
_sym_db.RegisterMessage(StartActivityRequest)

CancelActivityRequest = _reflection.GeneratedProtocolMessageType('CancelActivityRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELACTIVITYREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.CancelActivityRequest)
  })
_sym_db.RegisterMessage(CancelActivityRequest)

CompleteManualActivityRequest = _reflection.GeneratedProtocolMessageType('CompleteManualActivityRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETEMANUALACTIVITYREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.CompleteManualActivityRequest)
  })
_sym_db.RegisterMessage(CompleteManualActivityRequest)

SubscribeActivitiesRequest = _reflection.GeneratedProtocolMessageType('SubscribeActivitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEACTIVITIESREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.SubscribeActivitiesRequest)
  })
_sym_db.RegisterMessage(SubscribeActivitiesRequest)

SubscribeActivityLogRequest = _reflection.GeneratedProtocolMessageType('SubscribeActivityLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEACTIVITYLOGREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.SubscribeActivityLogRequest)
  })
_sym_db.RegisterMessage(SubscribeActivityLogRequest)

SubscribeGlobalStatusRequest = _reflection.GeneratedProtocolMessageType('SubscribeGlobalStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEGLOBALSTATUSREQUEST,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.SubscribeGlobalStatusRequest)
  })
_sym_db.RegisterMessage(SubscribeGlobalStatusRequest)

GlobalActivityStatus = _reflection.GeneratedProtocolMessageType('GlobalActivityStatus', (_message.Message,), {
  'DESCRIPTOR' : _GLOBALACTIVITYSTATUS,
  '__module__' : 'yamcs.protobuf.activities.activities_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.activities.GlobalActivityStatus)
  })
_sym_db.RegisterMessage(GlobalActivityStatus)


DESCRIPTOR._options = None

_ACTIVITIESAPI = _descriptor.ServiceDescriptor(
  name='ActivitiesApi',
  full_name='yamcs.protobuf.activities.ActivitiesApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1411,
  serialized_end=3236,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListActivities',
    full_name='yamcs.protobuf.activities.ActivitiesApi.ListActivities',
    index=0,
    containing_service=None,
    input_type=_LISTACTIVITIESREQUEST,
    output_type=_LISTACTIVITIESRESPONSE,
    serialized_options=b'\212\222\003\'\n%/api/activities/{instance}/activities',
  ),
  _descriptor.MethodDescriptor(
    name='GetActivity',
    full_name='yamcs.protobuf.activities.ActivitiesApi.GetActivity',
    index=1,
    containing_service=None,
    input_type=_GETACTIVITYREQUEST,
    output_type=yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYINFO,
    serialized_options=b'\212\222\0032\n0/api/activities/{instance}/activities/{activity}',
  ),
  _descriptor.MethodDescriptor(
    name='GetActivityLog',
    full_name='yamcs.protobuf.activities.ActivitiesApi.GetActivityLog',
    index=2,
    containing_service=None,
    input_type=_GETACTIVITYLOGREQUEST,
    output_type=_GETACTIVITYLOGRESPONSE,
    serialized_options=b'\212\222\0036\n4/api/activities/{instance}/activities/{activity}/log',
  ),
  _descriptor.MethodDescriptor(
    name='StartActivity',
    full_name='yamcs.protobuf.activities.ActivitiesApi.StartActivity',
    index=3,
    containing_service=None,
    input_type=_STARTACTIVITYREQUEST,
    output_type=yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYINFO,
    serialized_options=b'\212\222\003;\032%/api/activities/{instance}/activities:\022activityDefinition',
  ),
  _descriptor.MethodDescriptor(
    name='CancelActivity',
    full_name='yamcs.protobuf.activities.ActivitiesApi.CancelActivity',
    index=4,
    containing_service=None,
    input_type=_CANCELACTIVITYREQUEST,
    output_type=yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYINFO,
    serialized_options=b'\212\222\0039\0327/api/activities/{instance}/activities/{activity}:cancel',
  ),
  _descriptor.MethodDescriptor(
    name='CompleteManualActivity',
    full_name='yamcs.protobuf.activities.ActivitiesApi.CompleteManualActivity',
    index=5,
    containing_service=None,
    input_type=_COMPLETEMANUALACTIVITYREQUEST,
    output_type=yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYINFO,
    serialized_options=b'\212\222\003>\0329/api/activities/{instance}/activities/{activity}:complete:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeGlobalStatus',
    full_name='yamcs.protobuf.activities.ActivitiesApi.SubscribeGlobalStatus',
    index=6,
    containing_service=None,
    input_type=_SUBSCRIBEGLOBALSTATUSREQUEST,
    output_type=_GLOBALACTIVITYSTATUS,
    serialized_options=b'\332\222\003\030\n\026global-activity-status',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeActivities',
    full_name='yamcs.protobuf.activities.ActivitiesApi.SubscribeActivities',
    index=7,
    containing_service=None,
    input_type=_SUBSCRIBEACTIVITIESREQUEST,
    output_type=yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYINFO,
    serialized_options=b'\332\222\003\014\n\nactivities',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeActivityLog',
    full_name='yamcs.protobuf.activities.ActivitiesApi.SubscribeActivityLog',
    index=8,
    containing_service=None,
    input_type=_SUBSCRIBEACTIVITYLOGREQUEST,
    output_type=yamcs_dot_protobuf_dot_activities_dot_activities__pb2._ACTIVITYLOGINFO,
    serialized_options=b'\332\222\003\016\n\014activity-log',
  ),
  _descriptor.MethodDescriptor(
    name='ListExecutors',
    full_name='yamcs.protobuf.activities.ActivitiesApi.ListExecutors',
    index=9,
    containing_service=None,
    input_type=_LISTEXECUTORSREQUEST,
    output_type=_LISTEXECUTORSRESPONSE,
    serialized_options=b'\212\222\003&\n$/api/activities/{instance}/executors',
  ),
  _descriptor.MethodDescriptor(
    name='ListScripts',
    full_name='yamcs.protobuf.activities.ActivitiesApi.ListScripts',
    index=10,
    containing_service=None,
    input_type=_LISTSCRIPTSREQUEST,
    output_type=_LISTSCRIPTSRESPONSE,
    serialized_options=b'\212\222\003$\n\"/api/activities/{instance}/scripts',
  ),
])
_sym_db.RegisterServiceDescriptor(_ACTIVITIESAPI)

DESCRIPTOR.services_by_name['ActivitiesApi'] = _ACTIVITIESAPI

# @@protoc_insertion_point(module_scope)
